@@ -245,7 +245,7 @@ static void WriteBottomCalLine (void);
 static void WriteIntermediateCalLine (void);
 static void WriteCalDays (void);
 
-static void PrintJSONString(char const *s)
+void PrintJSONString(char const *s)
 {
     while (*s) {
 	switch(*s) {
@@ -262,14 +262,14 @@ static void PrintJSONString(char const *s)
     }
 }
 
-static void PrintJSONKeyPairInt(char const *name, int val)
+void PrintJSONKeyPairInt(char const *name, int val)
 {
     printf("\"");
     PrintJSONString(name);
     printf("\":%d, ", val);
 }
 
-static void PrintJSONKeyPairString(char const *name, char const *val)
+void PrintJSONKeyPairString(char const *name, char const *val)
 {
     /* If value is blank, skip it! */
     if (!val || !*val) {
@@ -283,7 +283,7 @@ static void PrintJSONKeyPairString(char const *name, char const *val)
     printf("\", ");
 }
 
-static void PrintJSONKeyPairDate(char const *name, int jul)
+void PrintJSONKeyPairDate(char const *name, int jul)
 {
     int y, m, d;
     if (jul == NO_DATE) {
@@ -297,7 +297,7 @@ static void PrintJSONKeyPairDate(char const *name, int jul)
 
 }
 
-static void PrintJSONKeyPairDateTime(char const *name, int dt)
+void PrintJSONKeyPairDateTime(char const *name, int dt)
 {
     int y, m, d, h, i, k;
     if (dt == NO_TIME) {
@@ -315,6 +315,21 @@ static void PrintJSONKeyPairDateTime(char const *name, int dt)
 
 }
 
+void PrintJSONKeyPairTime(char const *name, int t)
+{
+    int h, i;
+    if (t == NO_TIME) {
+	/* Skip it! */
+	return;
+    }
+    h = t / 60;
+    i = t % 60;
+    printf("\"");
+    PrintJSONString(name);
+    printf("\":\"%02d:%02d\", ", h, i);
+
+}
+
 #ifdef REM_USE_WCHAR
 static void PutWideChar(wchar_t const wc)
 {
@@ -495,7 +510,7 @@ ComputeCalWidth(int x)
 	return 80;
     }
     if (w.ws_col < 71) {
-	return 80;
+	return 71;
     }
     return w.ws_col;
 }
@@ -778,8 +793,13 @@ static int WriteCalendarRow(void)
 	if (i < wd || d+i-wd>DaysInMonth(m, y))
 	    PrintLeft("", ColSpaces, ' ');
 	else {
-	    sprintf(buf, "%d", d+i-wd);
-	    PrintLeft(buf, ColSpaces, ' ');
+	    sprintf(buf, "%d ", d+i-wd);
+	    if (OrigJul+i == RealToday) {
+		PrintLeft(buf, ColSpaces-1, '*');
+		PutChar(' ');
+	    } else {
+		PrintLeft(buf, ColSpaces, ' ');
+	    }
 	}
 	gon();
 	DRAW(tb);
@@ -2081,8 +2101,6 @@ char const *SynthesizeTag(void)
     unsigned char buf[16];
     static char out[128];
     MD5Init(&ctx);
-    MD5Update(&ctx, (unsigned char *) FileName, strlen(FileName));
-    MD5Update(&ctx, (unsigned char *) &LineNo, sizeof(LineNo));
     MD5Update(&ctx, (unsigned char *) CurLine, strlen(CurLine));
     MD5Final(buf, &ctx);
     sprintf(out, "__syn__%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
