@@ -417,6 +417,9 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    switch(tok.type) {
 	    case T_Time:
 	    case T_LongTime:
+	    case T_Year:
+	    case T_Day:
+	    case T_Number:
 		if (tok.val != 0) {
 		    tim->duration = tok.val;
 		} else {
@@ -984,7 +987,7 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul)
 	break;
 
     case RUN_TYPE:
-	system(DBufValue(&buf));
+	System(DBufValue(&buf));
 	break;
 
     default: /* Unknown/illegal type? */
@@ -1099,10 +1102,24 @@ int DoSatRemind(Trigger *trig, TimeTrig *tt, ParsePtr p)
     iter = 0;
     start = trig->scanfrom;
     while (iter++ < MaxSatIter) {
-	jul = ComputeTriggerNoAdjustDuration(start, trig, tt, &r, 1);
+	jul = ComputeTriggerNoAdjustDuration(start, trig, tt, &r, 1, 0);
 	if (r) {
 	    if (r == E_CANT_TRIG) return OK; else return r;
 	}
+	if (jul != start && trig->duration_days) {
+	    jul = ComputeTriggerNoAdjustDuration(start, trig, tt, &r, 1, trig->duration_days);
+	    if (r) {
+		if (r == E_CANT_TRIG) return OK; else return r;
+	    }
+	} else if (jul == start) {
+	    if (tt->ttime != NO_TIME) {
+		trig->eventstart = MINUTES_PER_DAY * r + tt->ttime;
+		if (tt->duration != NO_TIME) {
+		    trig->eventduration = tt->duration;
+		}
+	    }
+	    SaveAllTriggerInfo(trig, tt, jul, tt->ttime, 1);
+	}
 	if (jul == -1) {
 	    return E_EXPIRED;
 	}
@@ -1240,7 +1257,7 @@ int DoMsgCommand(char const *cmd, char const *msg)
     }
     r = OK;
 
-    system(DBufValue(&execBuffer));
+    System(DBufValue(&execBuffer));
 
 finished:
     DBufFree(&buf);
