@@ -8,7 +8,7 @@
 /*                                                             */
 /*  This file is part of REMIND.                               */
 /*                                                             */
-/*  REMIND is Copyright (C) 1992-2018 by Dianne Skoll          */
+/*  REMIND is Copyright (C) 1992-2020 by Dianne Skoll          */
 /*  This file is Copyright (C) 1993 by Laurent Duperval and    */
 /*  Dianne Skoll.                                              */
 /*                                                             */
@@ -242,7 +242,8 @@ EXTERN char *ErrMsg[] =
     "Can't convert between time zones",
     "No files matching *.rem",
     "String too long",
-    "Time specified twice"
+    "Time specified twice",
+    "Cannot specify DURATION without specifying AT"
 
 #else /* ISOLATIN1 */
     "Ok",
@@ -347,7 +348,8 @@ EXTERN char *ErrMsg[] =
     "Can't convert between time zones",
     "No files matching *.rem",
     "String too long",
-    "Time specified twice"
+    "Time specified twice",
+    "Cannot specify DURATION without specifying AT"
 #endif /* ISOLATIN1 */
 };
 #endif /* MK_GLOBALS */
@@ -357,7 +359,7 @@ EXTERN char *ErrMsg[] =
 #define L_USAGE_OVERRIDE 1
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-2018 Dianne Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-2020 Dianne Skoll\n", VERSION, L_LANGNAME);
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
 #endif
