@@ -1370,6 +1370,16 @@ ClearLastTriggers(void)
     LastTimeTrig.duration = NO_TIME;
 }
 
+void
+SaveAllTriggerInfo(Trigger const *t, TimeTrig const *tt, int trigdate, int trigtime, int valid)
+{
+    SaveLastTrigger(t);
+    SaveLastTimeTrig(tt);
+    LastTriggerDate = trigdate;
+    LastTriggerTime = trigtime;
+    LastTrigValid = valid;
+}
+
 void
 SaveLastTrigger(Trigger const *t)
 {
@@ -1382,3 +1392,14 @@ SaveLastTimeTrig(TimeTrig const *t)
 {
     memcpy(&LastTimeTrig, t, sizeof(LastTimeTrig));
 }
+
+/* Wrapper to ignore warnings about ignoring return value of system() */
+void
+System(char const *cmd)
+{
+    int r;
+    r = system(cmd);
+    if (r == 0) {
+	r = 1;
+    }
+}
