@@ -37,6 +37,7 @@ int ShouldTriggerReminder (Trigger *t, TimeTrig *tim, int jul, int *err);
 int DoSubst (ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int jul, int mode);
 int DoSubstFromString (char const *source, DynamicBuffer *dbuf, int jul, int tim);
 int ParseLiteralDate (char const **s, int *jul, int *tim);
+int ParseLiteralTime (char const **s, int *tim);
 int EvalExpr (char const **e, Value *v, ParsePtr p);
 int DoCoerce (char type, Value *v);
 void PrintValue  (Value *v, FILE *fp);
@@ -89,7 +90,7 @@ char const *FindInitialToken (Token *tok, char const *s);
 void FindToken (char const *s, Token *tok);
 void FindNumericToken (char const *s, Token *t);
 int ComputeTrigger (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals);
-int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals);
+int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals, int duration_days);
 int AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int save_in_globals);
 int ComputeScanStart(int today, Trigger *trig, TimeTrig *tt);
 char *StrnCpy (char *dest, char const *source, int n);
@@ -148,6 +149,15 @@ char const *SynthesizeTag(void);
 void ClearLastTriggers(void);
 void SaveLastTrigger(Trigger const *t);
 void SaveLastTimeTrig(TimeTrig const *t);
+void SaveAllTriggerInfo(Trigger const *t, TimeTrig const *tt, int trigdate, int trigtime, int valid);
+
 void PerIterationInit(void);
 char const *Decolorize(int r, int g, int b);
 char const *Colorize(int r, int g, int b);
+void PrintJSONString(char const *s);
+void PrintJSONKeyPairInt(char const *name, int val);
+void PrintJSONKeyPairString(char const *name, char const *val);
+void PrintJSONKeyPairDate(char const *name, int jul);
+void PrintJSONKeyPairDateTime(char const *name, int dt);
+void PrintJSONKeyPairTime(char const *name, int t);
+void System(char const *cmd);
