@@ -454,11 +454,7 @@ AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int sav
 
     }
     if (save_in_globals) {
-	LastTriggerTime = tim->ttime;
-	SaveLastTimeTrig(tim);
-	SaveLastTrigger(trig);
-	LastTriggerDate = r;
-	LastTrigValid = 1;
+	SaveAllTriggerInfo(trig, tim, r, tim->ttime, 1);
     }
     return r;
 }
@@ -474,10 +470,29 @@ AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int sav
 int ComputeTrigger(int today, Trigger *trig, TimeTrig *tim,
 		   int *err, int save_in_globals)
 {
-    int r = ComputeTriggerNoAdjustDuration(today, trig, tim, err, save_in_globals);
+    int r = ComputeTriggerNoAdjustDuration(today, trig, tim, err, save_in_globals, 0);
     if (*err != OK) {
 	return r;
     }
+    if (r == today) {
+	if (tim->ttime != NO_TIME) {
+	    trig->eventstart = MINUTES_PER_DAY * r + tim->ttime;
+	    if (tim->duration != NO_TIME) {
+		trig->eventduration = tim->duration;
+	    }
+	}
+	if (save_in_globals) {
+	    SaveAllTriggerInfo(trig, tim, r, tim->ttime, 1);
+	}
+	return r;
+    }
+
+    if (trig->duration_days) {
+	r = ComputeTriggerNoAdjustDuration(today, trig, tim, err, save_in_globals, trig->duration_days);
+	if (*err != OK) {
+	    return r;
+	}
+    }
     r = AdjustTriggerForDuration(today, r, trig, tim, save_in_globals);
     return r;
 }
@@ -491,10 +506,10 @@ int ComputeTrigger(int today, Trigger *trig, TimeTrig *tim,
 /*                                                             */
 /***************************************************************/
 int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
-				   int *err, int save_in_globals)
+				   int *err, int save_in_globals, int duration_days)
 {
     int nattempts = 0,
-	start = today - trig->duration_days,
+	start = today - duration_days,
 	nextstart = 0,
 	y, m, d, omit,
 	result;
@@ -561,7 +576,7 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 	}
 
 	/** FIXME: Fix bad interaction with SATISFY... need to rethink!!! */
-	if (result+trig->duration_days >= today &&
+	if (result+duration_days >= today &&
 	    (trig->skip != SKIP_SKIP || !omit)) {
 	    if (save_in_globals) {
 		LastTriggerDate = result;  /* Save in global var */
